==> neo4django-0.1.3.tar.gz: neo4django-0.1.3/reg_settings.py <==
options={
	}
tests=[
	'test_json_serialize',
	'test_unique',
	'test_default_parents_index',
	'test_indexed_types',
	'test_create',
	'test_delete',
	'test_iter',
	'test_dates',
	'test_all',
	'test_get',
	'test_filter_exact',
	'test_filter_iexact',
	'test_filter_range',
	'test_exclude_exact',
	'test_basic_relationship',
	'test_one_to_many',
	'test_many_to_one',
	'test_related_one_to_many',
	'test_related_many_to_one',
	'test_one_to_one',
	'test_ordering',
	'test_relationship_model',
	'test_multinode_setting',
	'test_save_delete',
	'test_prop',
	'test_none_prop',
	'test_integer',
	'test_date_constructor',
	'test_date_prop',
	'test_datetime_constructor',
	'test_datetime_auto_now',
	'test_datetime_auto_now_add',
	'test_date_auto_now',
	'test_date_auto_now_add',
	'test_type_nodes',
	'test_model_inheritance',
	'test_nodemodel_independence',
	'test_array_property_validator',
	'test_int_array_property_validator',
	'test_str_array_property_validator',
	'test_url_array_property_validator',
	'test_basic_indexed_query',
	'test_negated_query',
	'test_unindexed_query',
	'test_complex_query',
	'test_type_query',
	'test_filter_gt',
	'test_filter_gte',
	'test_filter_lt',
	'test_filter_lte',
	'test_filter_date_range',
	'test_model_casting',
	'test_model_casting_validation',
	'test_model_copy',
	'test_one_to_one',
	'test_prop_metadata',
	'test_rel_metadata']
should_fail=[
	'test_dates',
	'test_filter_iexact',
	'test_relationship_model',
	'test_datetime_auto_now_add',
	'test_nodemodel_independence',
	'test_str_array_property_validator',
	'test_url_array_property_validator',
	'test_type_query',
	'test_model_casting_validation',]

==> neo4django-0.1.4.tar.gz: neo4django-0.1.4/reg_settings.py <==
options={
	}
tests=[
	'test_json_serialize',
	'test_unique',
	'test_default_parents_index',
	'test_indexed_types',
	'test_create',
	'test_delete',
	'test_iter',
	'test_dates',
	'test_all',
	'test_get',
	'test_filter_exact',
	'test_filter_iexact',
	'test_filter_range',
	'test_exclude_exact',
	'test_basic_relationship',
	'test_one_to_many',
	'test_many_to_one',
	'test_related_one_to_many',
	'test_related_many_to_one',
	'test_one_to_one',
	'test_ordering',
	'test_relationship_model',
	'test_multinode_setting',
	'test_save_delete',
	'test_prop',
	'test_none_prop',
	'test_integer',
	'test_date_constructor',
	'test_date_prop',
	'test_datetime_constructor',
	'test_datetime_auto_now',
	'test_datetime_auto_now_add',
	'test_date_auto_now',
	'test_date_auto_now_add',
	'test_type_nodes',
	'test_model_inheritance',
	'test_nodemodel_independence',
	'test_array_property_validator',
	'test_int_array_property_validator',
	'test_str_array_property_validator',
	'test_url_array_property_validator',
	'test_basic_indexed_query',
	'test_negated_query',
	'test_unindexed_query',
	'test_complex_query',
	'test_type_query',
	'test_filter_gt',
	'test_filter_gte',
	'test_filter_lt',
	'test_filter_lte',
	'test_filter_date_range',
	'test_model_casting',
	'test_model_casting_validation',
	'test_model_copy',
	'test_basic_relationship_manager',
	'test_one_to_one',
	'test_rel_metadata',
	'test_prop_metadata',
	'test_rel_self',
	'test_rel_string_target']
should_fail=[
	'test_dates',
	'test_filter_iexact',
	'test_relationship_model',
	'test_datetime_auto_now_add',
	'test_nodemodel_independence',
	'test_str_array_property_validator',
	'test_url_array_property_validator',
	'test_type_query',
	'test_model_casting_validation',
]
